@@ -49,20 +49,25 @@ struct pevt_stage1
 
 
 static void mkdir_p (char *dir);
+static char *log_create_filename (char *channame);
 
 
 static char *
 scrollback_get_filename (session *sess, char *buf, int max)
 {
-	char *net;
+	char *net, *chan;
 
 	net = server_get_network (sess->server, FALSE);
 	if (!net)
 		return NULL;
 
-	snprintf (buf, max, "%s/%s/%s/scrollback.txt", get_xdir_fs (), net, sess->channel);
+	snprintf (buf, max, "%s/scrollback/%s/%s.txt", get_xdir_fs (), net, "");
 	mkdir_p (buf);
 
+	chan = log_create_filename (sess->channel);
+	snprintf (buf, max, "%s/scrollback/%s/%s.txt", get_xdir_fs (), net, chan);
+	free (chan);
+
 	return buf;
 }
 
@@ -284,7 +289,7 @@ scrollback_load (session *sess)
 	{
 		text = ctime (&stamp);
 		text[24] = 0;	/* get rid of the \n */
-		snprintf (buf, sizeof (buf), "*\tLoaded log from %s", text);
+		snprintf (buf, sizeof (buf), "\n*\t%s %s\n\n", _("Loaded log from"), text);
 		fe_print_text (sess, buf, 0);
 		/*EMIT_SIGNAL (XP_TE_GENMSG, sess, "*", buf, NULL, NULL, NULL, 0);*/
 	}
@@ -673,7 +678,7 @@ iso_8859_1_to_utf8 (unsigned char *text, int len, gsize *bytes_written)
 	};
 
 	if (len == -1)
-		len = strlen (text);
+		len = strlen ((char *) text);
 
 	/* worst case scenario: every byte turns into 3 bytes */
 	res = output = g_malloc ((len * 3) + 1);
@@ -737,13 +742,13 @@ text_validate (char **text, int *len)
 	if (prefs.utf8_locale)
 #endif
 		/* fallback to iso-8859-1 */
-		utf = iso_8859_1_to_utf8 (*text, *len, &utf_len);
+		utf = iso_8859_1_to_utf8 ((char *) *text, *len, &utf_len);
 	else
 	{
 		/* fallback to locale */
 		utf = g_locale_to_utf8 (*text, *len, 0, &utf_len, NULL);
 		if (!utf)
-			utf = iso_8859_1_to_utf8 (*text, *len, &utf_len);
+			utf = iso_8859_1_to_utf8 ((char *) *text, *len, &utf_len);
 	}
 
 	if (!utf) 
@@ -1363,7 +1368,7 @@ pevent_load_defaults ()
 			free (pntevts_text[i]);
 
 		/* make-te.c sets this 128 flag (DON'T call gettext() flag) */
-		if (te[i].num_args & 128)
+		if (te[i].num_args & 128 || !strcmp (te[i].def, ""))
 			pntevts_text[i] = strdup (te[i].def);
 		else
 			pntevts_text[i] = strdup (_(te[i].def));
@@ -1387,7 +1392,7 @@ pevent_make_pntevts ()
 			fe_message (out, FE_MSG_WARN);
 			free (pntevts_text[i]);
 			/* make-te.c sets this 128 flag (DON'T call gettext() flag) */
-			if (te[i].num_args & 128)
+			if (te[i].num_args & 128 || !strcmp (te[i].def, ""))
 				pntevts_text[i] = strdup (te[i].def);
 			else
 				pntevts_text[i] = strdup (_(te[i].def));
@@ -1567,7 +1572,7 @@ pevent_check_all_loaded ()
 			snprintf(out, sizeof(out), "The data for event %s failed to load. Reverting to defaults.\nThis may be because a new version of XChat is loading an old config file.\n\nCheck all print event texts are correct", evtnames[i]);
 			   gtkutil_simpledialog(out); */
 			/* make-te.c sets this 128 flag (DON'T call gettext() flag) */
-			if (te[i].num_args & 128)
+			if (te[i].num_args & 128 || !strcmp (te[i].def, ""))
 				pntevts_text[i] = strdup (te[i].def);
 			else
 				pntevts_text[i] = strdup (_(te[i].def));
